@@ -18,9 +18,9 @@ import types
 import warnings
 
 from abc import ABCMeta
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from functools import singledispatch
-from typing import Callable, Optional, Union
+from typing import TypeAlias
 
 import numpy as np
 
@@ -41,7 +41,6 @@ from pytensor.tensor.random.utils import normalize_size_param
 from pytensor.tensor.rewriting.shape import ShapeFeature
 from pytensor.tensor.utils import _parse_gufunc_signature
 from pytensor.tensor.variable import TensorVariable
-from typing_extensions import TypeAlias
 
 from pymc.distributions.shape_utils import (
     Dims,
@@ -62,6 +61,7 @@ from pymc.model.core import new_or_existing_block_model_access
 from pymc.printing import str_for_dist
 from pymc.pytensorf import (
     collect_default_updates,
+    collect_default_updates_inner_fgraph,
     constant_fold,
     convert_observed_data,
     floatX,
@@ -79,9 +79,9 @@ __all__ = [
     "SymbolicRandomVariable",
 ]
 
-DIST_PARAMETER_TYPES: TypeAlias = Union[np.ndarray, int, float, TensorVariable]
+DIST_PARAMETER_TYPES: TypeAlias = np.ndarray | int | float | TensorVariable
 
-vectorized_ppc: contextvars.ContextVar[Optional[Callable]] = contextvars.ContextVar(
+vectorized_ppc: contextvars.ContextVar[Callable | None] = contextvars.ContextVar(
     "vectorized_ppc", default=None
 )
 
@@ -103,7 +103,7 @@ class FiniteLogpPointRewrite(GraphRewriter):
 
         for nd in local_fgraph_topo:
             if nd not in to_replace_set and isinstance(
-                nd.op, (RandomVariable, SymbolicRandomVariable)
+                nd.op, RandomVariable | SymbolicRandomVariable
             ):
                 replace_with_support_point.append(nd.out)
                 to_replace_set.add(nd)
@@ -133,7 +133,7 @@ class FiniteLogpPointRewrite(GraphRewriter):
 
     def apply(self, fgraph):
         for node in fgraph.toposort():
-            if isinstance(node.op, (RandomVariable, SymbolicRandomVariable)):
+            if isinstance(node.op, RandomVariable | SymbolicRandomVariable):
                 fgraph.replace(node.out, support_point(node.out))
             elif isinstance(node.op, Scan):
                 new_node = self.rewrite_support_point_scan_node(node)
@@ -263,7 +263,7 @@ class SymbolicRandomVariable(OpFromGraph):
     (0 for scalar, 1 for vector, ...)
      """
 
-    ndims_params: Optional[Sequence[int]] = None
+    ndims_params: Sequence[int] | None = None
     """Number of core dimensions of the distribution's parameters."""
 
     signature: str = None
@@ -299,16 +299,17 @@ class SymbolicRandomVariable(OpFromGraph):
                 raise ValueError("ndim_supp or gufunc_signature must be provided")
 
         kwargs.setdefault("inline", True)
+        kwargs.setdefault("strict", True)
         super().__init__(*args, **kwargs)
 
-    def update(self, node: Node):
+    def update(self, node: Node) -> dict[Variable, Variable]:
         """Symbolic update expression for input random state variables
 
         Returns a dictionary with the symbolic expressions required for correct updating
         of random state input variables repeated function evaluations. This is used by
         `pytensorf.compile_pymc`.
         """
-        return {}
+        return collect_default_updates_inner_fgraph(node)
 
     def batch_ndim(self, node: Node) -> int:
         """Number of dimensions of the distribution's batch shape."""
@@ -327,7 +328,7 @@ class Distribution(metaclass=DistributionMeta):
         name: str,
         *args,
         rng=None,
-        dims: Optional[Dims] = None,
+        dims: Dims | None = None,
         initval=None,
         observed=None,
         total_size=None,
@@ -436,7 +437,7 @@ class Distribution(metaclass=DistributionMeta):
         cls,
         dist_params,
         *,
-        shape: Optional[Shape] = None,
+        shape: Shape | None = None,
         **kwargs,
     ) -> TensorVariable:
         """Creates a tensor variable corresponding to the `cls` distribution.
@@ -591,13 +592,13 @@ class _CustomDist(Distribution):
     def dist(
         cls,
         *dist_params,
-        logp: Optional[Callable] = None,
-        logcdf: Optional[Callable] = None,
-        random: Optional[Callable] = None,
-        support_point: Optional[Callable] = None,
-        ndim_supp: Optional[int] = None,
-        ndims_params: Optional[Sequence[int]] = None,
-        signature: Optional[str] = None,
+        logp: Callable | None = None,
+        logcdf: Callable | None = None,
+        random: Callable | None = None,
+        support_point: Callable | None = None,
+        ndim_supp: int | None = None,
+        ndims_params: Sequence[int] | None = None,
+        signature: str | None = None,
         dtype: str = "floatX",
         class_name: str = "CustomDist",
         **kwargs,
@@ -652,10 +653,10 @@ class _CustomDist(Distribution):
     def rv_op(
         cls,
         *dist_params,
-        logp: Optional[Callable],
-        logcdf: Optional[Callable],
-        random: Optional[Callable],
-        support_point: Optional[Callable],
+        logp: Callable | None,
+        logcdf: Callable | None,
+        random: Callable | None,
+        support_point: Callable | None,
         ndim_supp: int,
         ndims_params: Sequence[int],
         dtype: str,
@@ -702,24 +703,10 @@ class CustomSymbolicDistRV(SymbolicRandomVariable):
     symbolic random methods.
     """
 
-    default_output = -1
+    default_output = 0
 
     _print_name = ("CustomSymbolicDist", "\\operatorname{CustomSymbolicDist}")
 
-    def update(self, node: Node):
-        op = node.op
-        inner_updates = collect_default_updates(
-            inputs=op.inner_inputs, outputs=op.inner_outputs, must_be_shared=False
-        )
-
-        # Map inner updates to outer inputs/outputs
-        updates = {}
-        for rng, update in inner_updates.items():
-            inp_idx = op.inner_inputs.index(rng)
-            out_idx = op.inner_outputs.index(update)
-            updates[node.inputs[inp_idx]] = node.outputs[out_idx]
-        return updates
-
 
 @_support_point.register(CustomSymbolicDistRV)
 def dist_support_point(op, rv, *args):
@@ -743,12 +730,12 @@ class _CustomSymbolicDist(Distribution):
         cls,
         *dist_params,
         dist: Callable,
-        logp: Optional[Callable] = None,
-        logcdf: Optional[Callable] = None,
-        support_point: Optional[Callable] = None,
-        ndim_supp: Optional[int] = None,
-        ndims_params: Optional[Sequence[int]] = None,
-        signature: Optional[str] = None,
+        logp: Callable | None = None,
+        logcdf: Callable | None = None,
+        support_point: Callable | None = None,
+        ndim_supp: int | None = None,
+        ndims_params: Sequence[int] | None = None,
+        signature: str | None = None,
         dtype: str = "floatX",
         class_name: str = "CustomDist",
         **kwargs,
@@ -784,9 +771,9 @@ class _CustomSymbolicDist(Distribution):
         cls,
         *dist_params,
         dist: Callable,
-        logp: Optional[Callable],
-        logcdf: Optional[Callable],
-        support_point: Optional[Callable],
+        logp: Callable | None,
+        logcdf: Callable | None,
+        support_point: Callable | None,
         size=None,
         signature: str,
         class_name: str,
@@ -819,14 +806,17 @@ class _CustomSymbolicDist(Distribution):
         if logp is not None:
 
             @_logprob.register(rv_type)
-            def custom_dist_logp(op, values, size, *params, **kwargs):
-                return logp(values[0], *params[: len(dist_params)])
+            def custom_dist_logp(op, values, size, *inputs, **kwargs):
+                [value] = values
+                rv_params = inputs[: len(dist_params)]
+                return logp(value, *rv_params)
 
         if logcdf is not None:
 
             @_logcdf.register(rv_type)
-            def custom_dist_logcdf(op, value, size, *params, **kwargs):
-                return logcdf(value, *params[: len(dist_params)])
+            def custom_dist_logcdf(op, value, size, *inputs, **kwargs):
+                rv_params = inputs[: len(dist_params)]
+                return logcdf(value, *rv_params)
 
         if support_point is not None:
 
@@ -838,7 +828,7 @@ class _CustomSymbolicDist(Distribution):
                     *[
                         p
                         for p in params
-                        if not isinstance(p.type, (RandomType, RandomGeneratorType))
+                        if not isinstance(p.type, RandomType | RandomGeneratorType)
                     ],
                 )
 
@@ -859,22 +849,29 @@ class _CustomSymbolicDist(Distribution):
             dummy_dist_params = [dist_param.type() for dist_param in old_dist_params]
             dummy_rv = dist(*dummy_dist_params, dummy_size_param)
             dummy_params = [dummy_size_param, *dummy_dist_params]
-            dummy_updates_dict = collect_default_updates(inputs=dummy_params, outputs=(dummy_rv,))
+            updates_dict = collect_default_updates(inputs=dummy_params, outputs=(dummy_rv,))
+            rngs = updates_dict.keys()
+            rngs_updates = updates_dict.values()
             new_rv_op = rv_type(
-                inputs=dummy_params,
-                outputs=[*dummy_updates_dict.values(), dummy_rv],
+                inputs=[*dummy_params, *rngs],
+                outputs=[dummy_rv, *rngs_updates],
                 signature=signature,
             )
-            new_rv = new_rv_op(new_size, *dist_params)
+            new_rv = new_rv_op(new_size, *dist_params, *rngs)
 
             return new_rv
 
+        # RNGs are not passed as explicit inputs (because we usually don't know how many are needed)
+        # We retrieve them here
+        updates_dict = collect_default_updates(inputs=dummy_params, outputs=(dummy_rv,))
+        rngs = updates_dict.keys()
+        rngs_updates = updates_dict.values()
         rv_op = rv_type(
-            inputs=dummy_params,
-            outputs=[*dummy_updates_dict.values(), dummy_rv],
+            inputs=[*dummy_params, *rngs],
+            outputs=[dummy_rv, *rngs_updates],
             signature=signature,
         )
-        return rv_op(size, *dist_params)
+        return rv_op(size, *dist_params, *rngs)
 
     @staticmethod
     def _infer_final_signature(signature: str, n_inputs, n_updates) -> str:
@@ -1099,12 +1096,12 @@ class CustomDist:
        from pytensor.tensor import TensorVariable
 
         def pert(
-            low: Tensorvariable,
-            peak: Tensorvariable,
-            high: Tensorvariable,
-            lmbda: Tensorvariable,
-            size: Tensorvariable,
-        ) -> Tensorvariable:
+            low: TensorVariable,
+            peak: TensorVariable,
+            high: TensorVariable,
+            lmbda: TensorVariable,
+            size: TensorVariable,
+        ) -> TensorVariable:
             range = (high - low)
             s_alpha = 1 + lmbda * (peak - low) / range
             s_beta = 1 + lmbda * (high - peak) / range
@@ -1125,15 +1122,15 @@ class CustomDist:
         cls,
         name,
         *dist_params,
-        dist: Optional[Callable] = None,
-        random: Optional[Callable] = None,
-        logp: Optional[Callable] = None,
-        logcdf: Optional[Callable] = None,
-        support_point: Optional[Callable] = None,
+        dist: Callable | None = None,
+        random: Callable | None = None,
+        logp: Callable | None = None,
+        logcdf: Callable | None = None,
+        support_point: Callable | None = None,
         # TODO: Deprecate ndim_supp / ndims_params in favor of signature?
-        ndim_supp: Optional[int] = None,
-        ndims_params: Optional[Sequence[int]] = None,
-        signature: Optional[str] = None,
+        ndim_supp: int | None = None,
+        ndims_params: Sequence[int] | None = None,
+        signature: str | None = None,
         dtype: str = "floatX",
         **kwargs,
     ):
@@ -1188,14 +1185,14 @@ class CustomDist:
     def dist(
         cls,
         *dist_params,
-        dist: Optional[Callable] = None,
-        random: Optional[Callable] = None,
-        logp: Optional[Callable] = None,
-        logcdf: Optional[Callable] = None,
-        support_point: Optional[Callable] = None,
-        ndim_supp: Optional[int] = None,
-        ndims_params: Optional[Sequence[int]] = None,
-        signature: Optional[str] = None,
+        dist: Callable | None = None,
+        random: Callable | None = None,
+        logp: Callable | None = None,
+        logcdf: Callable | None = None,
+        support_point: Callable | None = None,
+        ndim_supp: int | None = None,
+        ndims_params: Sequence[int] | None = None,
+        signature: str | None = None,
         dtype: str = "floatX",
         **kwargs,
     ):
@@ -1369,7 +1366,7 @@ class PartialObservedRV(SymbolicRandomVariable):
 
 def create_partial_observed_rv(
     rv: TensorVariable,
-    mask: Union[np.ndarray, TensorVariable],
+    mask: np.ndarray | TensorVariable,
 ) -> tuple[
     tuple[TensorVariable, TensorVariable], tuple[TensorVariable, TensorVariable], TensorVariable
 ]:
