@@ -12,7 +12,6 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 from copy import copy, deepcopy
-from typing import Optional
 
 import pytensor
 
@@ -58,7 +57,7 @@ class ModelVar(Op):
 class ModelValuedVar(ModelVar):
     __props__ = ("transform",)
 
-    def __init__(self, transform: Optional[Transform] = None):
+    def __init__(self, transform: Transform | None = None):
         if transform is not None and not isinstance(transform, Transform):
             raise TypeError(f"transform must be None or RVTransform type, got {type(transform)}")
         self.transform = transform
@@ -182,8 +181,7 @@ def fgraph_from_model(
         for named_val in named_value_vars:
             idx = value_vars.index(named_val)
             value_vars[idx] = named_val
-    # Other variables that are in named_vars but are not any of the categories above
-    # E.g., MutableData, ConstantData, _dim_lengths
+    # Other variables that are in named_vars but are not any of the categories above (e.g., Data)
     # We use the same trick as deterministics!
     accounted_for = set(free_rvs + observed_rvs + potentials + old_deterministics + old_value_vars)
     other_named_vars = [
@@ -200,8 +198,8 @@ def fgraph_from_model(
 
     # Replace the following shared variables in the model:
     # 1. RNGs
-    # 2. MutableData (could increase memory usage significantly)
-    # 3. Mutable coords dim lengths
+    # 2. Data (could increase memory usage significantly)
+    # 3. Symbolic coords dim lengths
     shared_vars_to_copy = find_rng_nodes(model_vars)
     shared_vars_to_copy += [v for v in model.dim_lengths.values() if isinstance(v, SharedVariable)]
     shared_vars_to_copy += [v for v in model.named_vars.values() if isinstance(v, SharedVariable)]
@@ -262,7 +260,7 @@ def fgraph_from_model(
     inverse_memo = {v: k for k, v in memo.items()}
     for var, model_var in replacements:
         if not inlined_views and (
-            model_var.owner and isinstance(model_var.owner.op, (ModelDeterministic, ModelNamed))
+            model_var.owner and isinstance(model_var.owner.op, ModelDeterministic | ModelNamed)
         ):
             # Ignore extra identity that will be removed at the end
             var = var.owner.inputs[0]
@@ -322,9 +320,7 @@ def model_from_fgraph(fgraph: FunctionGraph) -> Model:
             var, value, *dims = model_var.owner.inputs
             transform = model_var.owner.op.transform
             model.free_RVs.append(var)
-            # PyMC does not allow setting transform when we pass a value_var. Why?
-            model.create_value_var(var, transform=None, value_var=value)
-            model.rvs_to_transforms[var] = transform
+            model.create_value_var(var, transform=transform, value_var=value)
             model.set_initval(var, initval=None)
         elif isinstance(model_var.owner.op, ModelObservedRV):
             var, value, *dims = model_var.owner.inputs
