@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -34,6 +34,7 @@ import pymc as pm
 from pymc.distributions.multivariate import (
     MultivariateIntervalTransform,
     _LKJCholeskyCov,
+    _LKJCorr,
     _OrderedMultinomial,
     posdef,
     quaddist_matrix,
@@ -54,7 +55,7 @@ from pymc.testing import (
     Rplus,
     Simplex,
     Vector,
-    assert_moment_is_expected,
+    assert_support_point_is_expected,
     check_logp,
     continuous_random_tester,
     seeded_numpy_distribution_builder,
@@ -558,7 +559,7 @@ class TestMatchesScipy:
     @pytest.mark.parametrize("x,eta,n,lp", LKJ_CASES)
     def test_lkjcorr(self, x, eta, n, lp):
         with pm.Model() as model:
-            pm.LKJCorr("lkj", eta=eta, n=n, transform=None)
+            pm.LKJCorr("lkj", eta=eta, n=n, transform=None, return_matrix=False)
 
         point = {"lkj": x}
         decimals = select_by_precision(float64=6, float32=4)
@@ -1002,7 +1003,7 @@ class TestLKJCholeskCov:
         assert draw_x3.shape == (3, 10, 3, 6)
 
 
-# Used for MvStudentT moment test
+# Used for MvStudentT support_point test
 rand1d = np.random.rand(2)
 rand2d = np.random.rand(2, 3)
 
@@ -1055,10 +1056,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_multinomial_moment(self, p, n, size, expected):
+    def test_multinomial_support_point(self, p, n, size, expected):
         with pm.Model() as model:
             pm.Multinomial("x", n=n, p=p, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "a, size, expected",
@@ -1089,10 +1090,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_dirichlet_moment(self, a, size, expected):
+    def test_dirichlet_support_point(self, a, size, expected):
         with pm.Model() as model:
             pm.Dirichlet("x", a=a, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, cov, size, expected",
@@ -1122,11 +1123,11 @@ class TestMoments:
             ),
         ],
     )
-    def test_mv_normal_moment(self, mu, cov, size, expected):
+    def test_mv_normal_support_point(self, mu, cov, size, expected):
         with pm.Model() as model:
             x = pm.MvNormal("x", mu=mu, cov=cov, size=size)
 
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "shape, n_zerosum_axes, expected",
@@ -1136,10 +1137,10 @@ class TestMoments:
             ((2, 5, 6), 3, np.zeros((2, 5, 6))),
         ],
     )
-    def test_zerosum_normal_moment(self, shape, n_zerosum_axes, expected):
+    def test_zerosum_normal_support_point(self, shape, n_zerosum_axes, expected):
         with pm.Model() as model:
             pm.ZeroSumNormal("x", shape=shape, n_zerosum_axes=n_zerosum_axes)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, size, expected",
@@ -1158,7 +1159,7 @@ class TestMoments:
             ),
         ],
     )
-    def test_car_moment(self, mu, size, expected):
+    def test_car_support_point(self, mu, size, expected):
         W = np.array(
             [[0.0, 1.0, 1.0, 0.0], [1.0, 0.0, 0.0, 1.0], [1.0, 0.0, 0.0, 1.0], [0.0, 1.0, 1.0, 0.0]]
         )
@@ -1166,7 +1167,7 @@ class TestMoments:
         alpha = 0.5
         with pm.Model() as model:
             pm.CAR("x", mu=mu, W=W, alpha=alpha, tau=tau, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "W, expected",
@@ -1175,10 +1176,10 @@ class TestMoments:
             (np.array([[0, 1], [1, 0]]), np.array([0, 0])),
         ],
     )
-    def test_icar_moment(self, W, expected):
+    def test_icar_support_point(self, W, expected):
         with pm.Model() as model:
             RV = pm.ICAR("x", W=W)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "nu, mu, cov, size, expected",
@@ -1193,11 +1194,11 @@ class TestMoments:
             ([2, 4], 0, np.eye(3), None, np.zeros((2, 3))),
         ],
     )
-    def test_mvstudentt_moment(self, nu, mu, cov, size, expected):
+    def test_mvstudentt_support_point(self, nu, mu, cov, size, expected):
         with pm.Model() as model:
             x = pm.MvStudentT("x", nu=nu, mu=mu, scale=cov, size=size)
 
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, rowchol, colchol, size, expected",
@@ -1209,13 +1210,13 @@ class TestMoments:
             (rand2d, np.eye(2), np.eye(3), (2, 5), np.full((2, 5, 2, 3), rand2d)),
         ],
     )
-    def test_matrixnormal_moment(self, mu, rowchol, colchol, size, expected):
+    def test_matrixnormal_support_point(self, mu, rowchol, colchol, size, expected):
         with pm.Model() as model:
             x = pm.MatrixNormal("x", mu=mu, rowchol=rowchol, colchol=colchol, size=size)
 
         # MatrixNormal logp is only implemented for 2d values
         check_logp = x.ndim == 2
-        assert_moment_is_expected(model, expected, check_finite_logp=check_logp)
+        assert_support_point_is_expected(model, expected, check_finite_logp=check_logp)
 
     @pytest.mark.parametrize(
         "alpha, K, size, expected",
@@ -1268,10 +1269,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_stickbreakingweights_moment(self, alpha, K, size, expected):
+    def test_stickbreakingweights_support_point(self, alpha, K, size, expected):
         with pm.Model() as model:
             pm.StickBreakingWeights("x", alpha=alpha, K=K, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "mu, covs, size, expected",
@@ -1296,10 +1297,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_kronecker_normal_moment(self, mu, covs, size, expected):
+    def test_kronecker_normal_support_point(self, mu, covs, size, expected):
         with pm.Model() as model:
             pm.KroneckerNormal("x", mu=mu, covs=covs, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "n, eta, size, expected",
@@ -1328,10 +1329,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_lkjcorr_moment(self, n, eta, size, expected):
+    def test_lkjcorr_support_point(self, n, eta, size, expected):
         with pm.Model() as model:
-            pm.LKJCorr("x", n=n, eta=eta, size=size)
-        assert_moment_is_expected(model, expected)
+            pm.LKJCorr("x", n=n, eta=eta, size=size, return_matrix=False)
+        assert_support_point_is_expected(model, expected)
 
     @pytest.mark.parametrize(
         "n, eta, size, expected",
@@ -1347,11 +1348,11 @@ class TestMoments:
             ),
         ],
     )
-    def test_lkjcholeskycov_moment(self, n, eta, size, expected):
+    def test_lkjcholeskycov_support_point(self, n, eta, size, expected):
         with pm.Model() as model:
             sd_dist = pm.Exponential.dist(1, size=(*to_tuple(size), n))
             pm.LKJCholeskyCov("x", n=n, eta=eta, sd_dist=sd_dist, size=size, compute_corr=False)
-        assert_moment_is_expected(model, expected, check_finite_logp=size is None)
+        assert_support_point_is_expected(model, expected, check_finite_logp=size is None)
 
     @pytest.mark.parametrize(
         "a, n, size, expected",
@@ -1382,10 +1383,10 @@ class TestMoments:
             ),
         ],
     )
-    def test_dirichlet_multinomial_moment(self, a, n, size, expected):
+    def test_dirichlet_multinomial_support_point(self, a, n, size, expected):
         with pm.Model() as model:
             pm.DirichletMultinomial("x", n=n, a=a, size=size)
-        assert_moment_is_expected(model, expected)
+        assert_support_point_is_expected(model, expected)
 
 
 class TestMvNormalCov(BaseTestDistributionRandom):
@@ -1443,11 +1444,9 @@ class TestMvNormalMisc:
         with pm.Model() as model:
             mu = pm.Normal("mu", 0.0, 1.0, size=3)
             sd_dist = pm.Exponential.dist(1.0, size=3)
-            # pylint: disable=unpacking-non-sequence
             chol, _, _ = pm.LKJCholeskyCov(
                 "chol_cov", n=3, eta=2, sd_dist=sd_dist, compute_corr=True
             )
-            # pylint: enable=unpacking-non-sequence
             mv = pm.MvNormal("mv", mu, chol=chol, size=4)
             prior = pm.sample_prior_predictive(samples=10, return_inferencedata=False)
 
@@ -1459,16 +1458,30 @@ class TestMvNormalMisc:
         with pm.Model() as model:
             mu = pm.Normal("mu", 0.0, 1.0, shape=3)
             sd_dist = pm.Exponential.dist(1.0, shape=3)
-            # pylint: disable=unpacking-non-sequence
             chol, corr, stds = pm.LKJCholeskyCov(
                 "chol_cov", n=3, eta=2, sd_dist=sd_dist, compute_corr=True
             )
-            # pylint: enable=unpacking-non-sequence
             mv = pm.MvNormal("mv", mu, cov=pm.math.dot(chol, chol.T), size=4)
             prior = pm.sample_prior_predictive(samples=10, return_inferencedata=False)
 
         assert prior["mv"].shape == (10, 4, 3)
 
+    def test_with_lkjcorr_matrix(
+        self,
+    ):
+        with pm.Model() as model:
+            corr = pm.LKJCorr("corr", n=3, eta=2, return_matrix=True)
+            pm.Deterministic("corr_mat", corr)
+            mv = pm.MvNormal("mv", 0.0, cov=corr, size=4)
+            prior = pm.sample_prior_predictive(samples=10, return_inferencedata=False)
+
+        assert prior["corr_mat"].shape == (10, 3, 3)  # square
+        assert (prior["corr_mat"][:, [0, 1, 2], [0, 1, 2]] == 1.0).all()  # 1.0 on diagonal
+        assert (prior["corr_mat"] == prior["corr_mat"].transpose(0, 2, 1)).all()  # symmetric
+        assert (
+            prior["corr_mat"].max() <= 1.0 and prior["corr_mat"].min() >= -1.0
+        )  # constrained between -1 and 1
+
     def test_issue_3758(self):
         np.random.seed(42)
         ndim = 50
@@ -1782,7 +1795,7 @@ class TestMvStudentTCov(BaseTestDistributionRandom):
         "mu": np.array([1.0, 2.0]),
         "scale": np.array([[2.0, 0.0], [0.0, 3.5]]),
     }
-    reference_dist = lambda self: ft.partial(self.mvstudentt_rng_fn, rng=self.get_random_state())
+    reference_dist = lambda self: ft.partial(self.mvstudentt_rng_fn, rng=self.get_random_state())  # noqa E731
     checks_to_run = [
         "check_pymc_params_match_rv_op",
         "check_pymc_draws_match_reference",
@@ -1985,7 +1998,7 @@ class TestWishart(BaseTestDistributionRandom):
         (1, 3, 3),
         (4, 5, 3, 3),
     ]
-    reference_dist = lambda self: ft.partial(self.wishart_rng_fn, rng=self.get_random_state())
+    reference_dist = lambda self: ft.partial(self.wishart_rng_fn, rng=self.get_random_state())  # noqa E731
     checks_to_run = [
         "check_rv_size",
         "check_pymc_params_match_rv_op",
@@ -2000,7 +2013,7 @@ class TestWishart(BaseTestDistributionRandom):
             if size is None:
                 expected_shape = (2, 3, 3)
             else:
-                expected_shape = size + (3, 3)
+                expected_shape = (*size, 3, 3)
 
             assert tuple(x.shape.eval()) == expected_shape
 
@@ -2114,7 +2127,7 @@ class TestKroneckerNormal(BaseTestDistributionRandom):
     sizes_to_check = [None, (), 1, (1,), 5, (4, 5), (2, 4, 2)]
     sizes_expected = [(N,), (N,), (1, N), (1, N), (5, N), (4, 5, N), (2, 4, 2, N)]
 
-    reference_dist = lambda self: ft.partial(self.kronecker_rng_fn, rng=self.get_random_state())
+    reference_dist = lambda self: ft.partial(self.kronecker_rng_fn, rng=self.get_random_state())  # noqa E731
     checks_to_run = [
         "check_pymc_draws_match_reference",
         "check_rv_size",
@@ -2137,7 +2150,7 @@ class TestOrderedMultinomial(BaseTestDistributionRandom):
 
 
 class TestLKJCorr(BaseTestDistributionRandom):
-    pymc_dist = pm.LKJCorr
+    pymc_dist = _LKJCorr
     pymc_dist_params = {"n": 3, "eta": 1.0}
     expected_rv_op_params = {"n": 3, "eta": 1.0}
 
@@ -2165,7 +2178,7 @@ class TestLKJCorr(BaseTestDistributionRandom):
             return (st.beta.rvs(size=(size, shape), a=beta, b=beta) - 0.5) * 2
 
         continuous_random_tester(
-            pm.LKJCorr,
+            _LKJCorr,
             {
                 "n": Domain([2, 10, 50], edges=(None, None)),
                 "eta": Domain([1.0, 10.0, 100.0], edges=(None, None)),
@@ -2190,7 +2203,7 @@ class TestLKJCorr(BaseTestDistributionRandom):
 )
 def test_LKJCorr_default_transform(shape):
     with pm.Model() as m:
-        x = pm.LKJCorr("x", n=2, eta=1, shape=shape)
+        x = pm.LKJCorr("x", n=2, eta=1, shape=shape, return_matrix=False)
     assert isinstance(m.rvs_to_transforms[x], MultivariateIntervalTransform)
     assert m.logp(sum=False)[0].type.shape == shape[:-1]
 
@@ -2370,7 +2383,7 @@ def test_mvnormal_no_cholesky_in_model_logp():
         data = np.ones((batch_size, n))
         pm.MvNormal("y", mu=mu, chol=pt.broadcast_to(chol, (batch_size, n, n)), observed=data)
 
-    contains_cholesky_op = lambda fgraph: any(
+    contains_cholesky_op = lambda fgraph: any(  # noqa E731
         isinstance(node.op, Cholesky) for node in fgraph.apply_nodes
     )
 
